@@ -17,12 +17,12 @@
 //!
 //! For a 3d game:
 //! ```toml
-//! heron = { version = "0.12.1", features = ["3d"] }
+//! heron = { version = "0.13.0", features = ["3d"] }
 //! ```
 //!
 //! For as 2d game:
 //! ```toml
-//! heron = { version = "0.12.1", features = ["2d"] }
+//! heron = { version = "0.13.0", features = ["2d"] }
 //! ```
 //!
 //! ### Feature flags
@@ -118,6 +118,7 @@
 //! * How to define the [`PhysicMaterial`]
 //! * How to listen to [`CollisionEvent`]
 //! * How to define [`RotationConstraints`]
+//! * How to define [`CustomCollisionShape`] for [`heron_rapier`]
 
 use bevy::app::{AppBuilder, Plugin};
 
@@ -138,7 +139,7 @@ pub mod prelude {
 
     #[allow(deprecated)]
     pub use crate::{
-        ext::*, stage, Acceleration, AxisAngle, CollisionEvent, CollisionLayers, CollisionShape,
+        stage, Acceleration, AxisAngle, CollisionEvent, CollisionLayers, CollisionShape, Damping,
         Gravity, PhysicMaterial, PhysicsLayer, PhysicsPlugin, PhysicsSystem, PhysicsTime,
         RigidBody, RotationConstraints, Velocity,
     };
